@@ -5,11 +5,13 @@ from txzmq.connection import ZmqConnection, ZmqEndpoint, ZmqEndpointType
 from txzmq.factory import ZmqFactory
 from txzmq.pubsub import ZmqPubConnection, ZmqSubConnection
 from txzmq.pushpull import ZmqPushConnection, ZmqPullConnection
-from txzmq.req_rep import ZmqREQConnection, ZmqREPConnection
+from txzmq.req_rep import ZmqREQConnection, ZmqREPConnection, \
+    ZmqRequestTimeoutError
 from txzmq.router_dealer import ZmqRouterConnection, ZmqDealerConnection
 
 
 __all__ = ['ZmqConnection', 'ZmqEndpoint', 'ZmqEndpointType', 'ZmqFactory',
            'ZmqPushConnection', 'ZmqPullConnection', 'ZmqPubConnection',
            'ZmqSubConnection', 'ZmqREQConnection', 'ZmqREPConnection',
-           'ZmqRouterConnection', 'ZmqDealerConnection']
+           'ZmqRouterConnection', 'ZmqDealerConnection',
+           'ZmqRequestTimeoutError']
